@@ -13,12 +13,12 @@ package Device::SMBus;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.13'; # VERSION
 
 # Dependencies
 use 5.010000;
 
-use Moose;
+use Moo;
 use Carp;
 
 use IO::File;
@@ -181,7 +181,7 @@ Device::SMBus - Control and read hardware devices with i2c(SMBus)
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 SYNOPSIS
 
@@ -388,7 +388,7 @@ The SMBus was defined by Intel in 1995. It carries clock, data, and instructions
 
 =item *
 
-This module provides a simplified object oriented interface to the libi2c-dev library for accessing electronic peripherals connected on the I2C bus. It uses Moose.
+This module provides a simplified object oriented interface to the libi2c-dev library for accessing electronic peripherals connected on the I2C bus. It uses Moo.
 
 =back
 
@@ -398,7 +398,7 @@ This module provides a simplified object oriented interface to the libi2c-dev li
 
 =item *
 
-L<Moose>
+L<Moo>
 
 =item *
 
